@@ -317,6 +317,8 @@ class Cone {
     void setBlocksizeHollowTri(long block_size);
     void setGBDegreeBound(const long degree_bound);
     void setGBMinDegree(const long min_degree);
+    void setModularGraing(long mod_gr);
+    void setChosenFusionRing(long fus_r);
 
     void setProjectName(const string& my_project);
     string getProjectName() const;
@@ -425,6 +427,7 @@ class Cone {
     size_t getNrNonsimpleFusionRings();
 
     const vector<vector<Matrix<Integer> > >& getFusionDataMatrix();
+    const vector<vector<Matrix<Integer> > >& getInductionMatrices();
 
     const FusionBasic& getFusionBasicCone();
 
@@ -480,6 +483,7 @@ class Cone {
     size_t getNrLatticePoints();
 
     const vector<Integer>& getSingleLatticePoint();
+    const vector<Integer>& getSingleFusionRing();
 
     const map<dynamic_bitset, int>& getSingularLocus();
     size_t getCodimSingularLocus();
@@ -498,6 +502,9 @@ class Cone {
     const map<dynamic_bitset, int>& getDualFaceLatticeOrbits();
     vector<size_t> getDualFVectorOrbits();
 
+    const vector<vector<dynamic_bitset> >& getModularGradings();
+    size_t getNrModularGradings();
+
     // the actual grading is Grading/GradingDenom
     vector<Integer> getGrading();
     Integer getGradingDenom();
@@ -702,10 +709,13 @@ class Cone {
     Matrix<Integer> ModuleGeneratorsOverOriginalMonoid;
     Matrix<Integer> Deg1Elements;
     vector<Integer> SingleLatticePoint;
+    vector<Integer> SingleFusionRing;
     Matrix<Integer> FusionRings;
     Matrix<Integer> SimpleFusionRings;
     Matrix<Integer> NonsimpleFusionRings;
     vector<vector<Matrix<Integer> > > FusionTables; // to avoid the name FusionData
+    vector<vector<Matrix<Integer> > > InductionMatrices;
+    vector<Integer> fusion_type_input;
 
     HilbertSeries HSeries;
     HilbertSeries EhrSeries;
@@ -796,6 +806,8 @@ class Cone {
     long block_size_hollow_tri;
     long gb_degree_bound;
     long gb_min_degree;
+    long modular_grading;
+    long chosen_fusion_ring;
 
     // if this is true we allow to change to a smaller integer type in the computation
     bool change_integer_type;
@@ -855,9 +867,12 @@ class Cone {
                 const vector<long long>& ValuesGradingOnMonoid,
                 bool verbose);
 
+    void make_modular_gradings(ConeProperties& ToCompute);
+    void add_fusion_ass_and_grading_constraints(ConeProperties& ToCompute);
     void try_symmetrization(ConeProperties& ToCompute);
     void try_approximation_or_projection(ConeProperties& ToCompute);
     void make_fusion_data(ConeProperties& ToCompute);
+    void make_induction_matrices(ConeProperties& ToCompute);
 
     void try_Hilbert_Series_from_lattice_points(const ConeProperties& ToCompute);
 
