@@ -170,6 +170,8 @@ ConeProperties all_options() {
     ret.set(ConeProperty::Lex);
     ret.set(ConeProperty::RevLex);
     ret.set(ConeProperty::DegLex);
+    ret.set(ConeProperty::ShortInt);
+    ret.set(ConeProperty::NoHeuristicMinimization);
     ret.set(ConeProperty::WritePreComp); // is not really an option, but taken care of in options.h
     ret.set(ConeProperty::NoPatching);
     ret.set(ConeProperty::NoCoarseProjection);
@@ -182,6 +184,7 @@ ConeProperties all_options() {
     ret.set(ConeProperty::CongOrderPatches);
     ret.set(ConeProperty::MinimizePolyEquations);
     ret.set(ConeProperty::DistributedComp);
+    ret.set(ConeProperty::UseModularGrading);
     return ret;
 }
 
@@ -320,9 +323,12 @@ void ConeProperties::check_lattice_ideal_goals() const{
 
 void ConeProperties::check_fusion_ring_props() const{
     ConeProperties copy(*this);
+    copy.reset(ConeProperty::BigInt);
     copy.reset(ConeProperty::FusionRings);
     copy.reset(ConeProperty::SimpleFusionRings);
+    copy.reset(ConeProperty::SingleFusionRing);
     copy.reset(ConeProperty::FusionData);
+    copy.reset(ConeProperty::InductionMatrices);
     copy.reset(ConeProperty::LatticePoints);
     copy.reset(ConeProperty::SingleLatticePointInternal);
     copy.reset(ConeProperty::SingleLatticePoint);
@@ -333,6 +339,12 @@ void ConeProperties::check_fusion_ring_props() const{
     copy.reset(ConeProperty::NoGradingDenom);
     copy.reset(ConeProperty::DistributedComp);
     copy.reset(ConeProperty::Projection);
+    copy.reset(ConeProperty::NoHeuristicMinimization);
+    copy.reset(ConeProperty::ShortInt);
+    copy.reset(ConeProperty::MinimizePolyEquations);
+    copy.reset(ConeProperty::ModularGradings);
+    copy.reset(ConeProperty::UseModularGrading);
+
 
     if (copy.any()) {
         errorOutput() << copy << endl;
@@ -410,7 +422,7 @@ void ConeProperties::set_fusion_default(const bool has_subring) {
 
     if(CPs.test(ConeProperty::LatticePoints) || CPs.test(ConeProperty::FusionRings)
         || CPs.test(ConeProperty::SimpleFusionRings) || CPs.test(ConeProperty::NonsimpleFusionRings)
-         || CPs.test(ConeProperty::FusionData) )
+         || CPs.test(ConeProperty::FusionData) || CPs.test(ConeProperty::SingleFusionRing) || CPs.test(ConeProperty::InductionMatrices) )
         return;
     if(CPs.test(ConeProperty::DefaultMode)){
         if(has_subring)
@@ -439,6 +451,14 @@ void ConeProperties::set_preconditions(bool inhomogeneous, bool numberfield) {
         CPs.reset(ConeProperty::NonsimpleFusionRings);
     }
 
+    if(CPs.test(ConeProperty::SingleFusionRing)){
+        CPs.set(ConeProperty::FusionRings);
+    }
+
+    if(CPs.test(ConeProperty::InductionMatrices) && !CPs.test(ConeProperty::SimpleFusionRings)){
+        CPs.set(ConeProperty::FusionRings);
+    }
+
     if(CPs.test(ConeProperty::FusionData) && !CPs.test(ConeProperty::SimpleFusionRings)){
         CPs.set(ConeProperty::FusionRings);
     }
@@ -784,7 +804,11 @@ void ConeProperties::check_compatibility_with_polynomial_constraints(bool inhomo
     wanted.reset(ConeProperty::FusionRings);
     wanted.reset(ConeProperty::SimpleFusionRings);
     wanted.reset(ConeProperty::FusionData);
+    wanted.reset(ConeProperty::InductionMatrices);
     wanted.reset(ConeProperty::NonsimpleFusionRings);
+    wanted.reset(ConeProperty::SingleFusionRing);
+    wanted.reset(ConeProperty::ModularGradings);
+    wanted.reset(ConeProperty::UseModularGrading);
     if(inhomogeneous)
         wanted.reset(ConeProperty::HilbertBasis);
     if(wanted.any()){
@@ -868,8 +892,10 @@ void ConeProperties::check_Q_permissible(bool after_implications) {
     copy.reset(ConeProperty::FusionRings);
     copy.reset(ConeProperty::SimpleFusionRings);
     copy.reset(ConeProperty::NonsimpleFusionRings);
+    copy.reset(ConeProperty::SingleFusionRing);
     copy.reset(ConeProperty::FusionData);
-;
+    copy.reset(ConeProperty::ShortInt);
+    copy.reset(ConeProperty::NoHeuristicMinimization);
     if (after_implications) {
         copy.reset(ConeProperty::Multiplicity);
         copy.reset(ConeProperty::Grading);
@@ -881,6 +907,36 @@ void ConeProperties::check_Q_permissible(bool after_implications) {
     }
 }
 
+void ConeProperties::check_conflicting_fusion_variants(){
+
+    size_t fusion_count = 0;
+    size_t latt_count = 0;
+    if(CPs.test(ConeProperty::FusionRings))
+        fusion_count++;
+    if(CPs.test(ConeProperty::SimpleFusionRings))
+        fusion_count++;
+    if(CPs.test(ConeProperty::SingleFusionRing))
+        fusion_count++;
+    if(CPs.test(ConeProperty::ModularGradings))
+        fusion_count++;
+    if(CPs.test(ConeProperty::LatticePoints)){
+        fusion_count++;
+        latt_count++;
+    }
+    if(CPs.test(ConeProperty::SingleLatticePoint)){
+        fusion_count++;
+        latt_count++;
+    }
+    if(fusion_count > 1 || latt_count > 1)
+        throw BadInputException("Conflicting properties for lattice points/fusion rings");
+    if(latt_count > 0 &&CPs.test(ConeProperty::UseModularGrading))
+        throw BadInputException("Conflicting properties for lattice points/fusion rings");
+    if(CPs.test(ConeProperty::ModularGradings) &&CPs.test(ConeProperty::UseModularGrading))
+        throw BadInputException("Conflicting properties for lattice points/fusion rings");
+    if(CPs.test(ConeProperty::SingleFusionRing) &&CPs.test(ConeProperty::SimpleFusionRings))
+        throw BadInputException("Conflicting properties for lattice points/fusion rings");
+}
+
 void ConeProperties::check_conflicting_variants() {
     if ((CPs.test(ConeProperty::BottomDecomposition) &&
          (CPs.test(ConeProperty::NoBottomDec) || CPs.test(ConeProperty::KeepOrder))) ||
@@ -897,8 +953,7 @@ void ConeProperties::check_conflicting_variants() {
         (CPs.test(ConeProperty::LinearOrderPatches) && CPs.test(ConeProperty::CongOrderPatches)) ||
         (CPs.test(ConeProperty::LatticePoints) && CPs.test(ConeProperty::SingleLatticePoint) ) ||
         // (CPs.test(ConeProperty::Symmetrize) && CPs.test(ConeProperty::SignedDec)) ||
-        (CPs.test(ConeProperty::Dynamic) && CPs.test(ConeProperty::Static)) ||
-        (CPs.test(ConeProperty::FusionRings) && CPs.test(ConeProperty::SimpleFusionRings))
+        (CPs.test(ConeProperty::Dynamic) && CPs.test(ConeProperty::Static) )
     )
         throw BadInputException("Contradictory algorithmic variants in options.");
 
@@ -1135,6 +1190,8 @@ vector<string> initializeCPN() {
     CPN.at(ConeProperty::GroebnerBasis) = "GroebnerBasis";
     CPN.at(ConeProperty::Lex) = "Lex";
     CPN.at(ConeProperty::RevLex) = "RevLex";
+    CPN.at(ConeProperty::ShortInt) = "ShortInt";
+    CPN.at(ConeProperty::NoHeuristicMinimization) = "NoHeuristicMinimization";
     CPN.at(ConeProperty::DegLex) = "DegLex";
     CPN.at(ConeProperty::NoPatching) = "NoPatching";
     CPN.at(ConeProperty::NoCoarseProjection) = "NoCoarseProjection";
@@ -1149,12 +1206,16 @@ vector<string> initializeCPN() {
     CPN.at(ConeProperty::LinearOrderPatches) = "LinearOrderPatches";
     CPN.at(ConeProperty::CongOrderPatches) = "CongOrderPatches";
     CPN.at(ConeProperty::FusionRings) = "FusionRings";
+    CPN.at(ConeProperty::ModularGradings) = "ModularGradings";
     CPN.at(ConeProperty::SimpleFusionRings) = "SimpleFusionRings";
     CPN.at(ConeProperty::NonsimpleFusionRings) = "NonsimpleFusionRings";
+    CPN.at(ConeProperty::SingleFusionRing) = "SingleFusionRing";
     CPN.at(ConeProperty::FusionData) = "FusionData";
+    CPN.at(ConeProperty::InductionMatrices) = "InductionMatrices";
+    CPN.at(ConeProperty::UseModularGrading) = "UseModularGrading";
 
     // detect changes in size of Enum, to remember to update CPN!
-    static_assert(ConeProperty::EnumSize == 160, "ConeProperties Enum size does not fit! Update cone_property.cpp!");
+    static_assert(ConeProperty::EnumSize == 166,"ConeProperties Enum size does not fit! Update cone_property.cpp!");
     // assert all fields contain an non-empty string
     for (size_t i = 0; i < ConeProperty::EnumSize; i++) {
         // bstd::cout << "iii " << i << "  " << CPN.at(i) << endl;
