@@ -100,6 +100,7 @@ enum Enum {
     CoveringFace,
     AxesScaling,
     SingleLatticePoint,
+    SingleFusionRing,
     END_ENUM_RANGE(LAST_VECTOR),
 
     // integer valued
@@ -210,7 +211,9 @@ enum Enum {
     //
     ClassGroup,
     //
+    ModularGradings,
     FusionData,
+    InductionMatrices,
     END_ENUM_RANGE(LAST_COMPLEX_STRUCTURE),
 
     //
@@ -258,6 +261,7 @@ enum Enum {
     LinearOrderPatches,
     CongOrderPatches,
     MinimizePolyEquations,
+    UseModularGrading,
     //
     Dynamic,
     Static,
@@ -268,6 +272,9 @@ enum Enum {
     RevLex,
     DegLex,
     //
+    ShortInt,
+    NoHeuristicMinimization,
+    //
     END_ENUM_RANGE(LAST_PROPERTY),
     //
     // ONLY FOR INTERNAL CONTROL
@@ -350,6 +357,7 @@ class ConeProperties {
     void set_fusion_partition_default();
 
     void check_conflicting_variants();
+    void check_conflicting_fusion_variants();
     void check_Q_permissible(bool after_implications);
     void check_monoid_goals() const;
     void check_lattice_ideal_goals() const;
