@@ -104,8 +104,10 @@ const nmz_float nmz_epsilon = 1.0e-12;
 /* this type is used in the entries of keys
  * it has to be able to hold number of generators */
 typedef unsigned int key_t;
+typedef unsigned short shortkey_t;
 
 NORMALIZ_DLL_EXPORT extern bool verbose;
+NORMALIZ_DLL_EXPORT extern bool running_input_file;
 NORMALIZ_DLL_EXPORT extern bool constructor_verbose;
 NORMALIZ_DLL_EXPORT extern bool polynomial_verbose;
 NORMALIZ_DLL_EXPORT extern bool talkative;
@@ -117,6 +119,8 @@ NORMALIZ_DLL_EXPORT extern bool int_max_value_dual_long_long_computed;
 NORMALIZ_DLL_EXPORT extern bool int_max_value_primary_long_computed;
 NORMALIZ_DLL_EXPORT extern bool int_max_value_primary_long_long_computed;
 NORMALIZ_DLL_EXPORT extern bool no_output_on_interrupt;
+NORMALIZ_DLL_EXPORT extern bool no_coord_transf;
+NORMALIZ_DLL_EXPORT extern bool write_lp_file;
 
 #ifdef NMZ_EXTENDED_TESTS
 NORMALIZ_DLL_EXPORT extern bool test_arith_overflow_full_cone, test_arith_overflow_dual_mode;
@@ -174,6 +178,7 @@ void MeasureTime(bool verbose, const std::string& step);
 double TimeSinceStart();
 void MeasureGlobalTime(bool verbose);
 void PrintTime(const struct timeval var_TIME_begin, bool verbose, const std::string& step);
+void noCoordTransf(bool onoff);
 
 void Check_Stop();
 
@@ -182,6 +187,7 @@ NORMALIZ_DLL_EXPORT extern double GlobalTimeBound;
 NORMALIZ_DLL_EXPORT extern double GlobalPredictionTimeBound;
 
 
+NORMALIZ_DLL_EXPORT extern long level_local_solutions; // transports <l> of -Q=<n>
 NORMALIZ_DLL_EXPORT extern long split_index_option; // transports <n> of -X=<n>
 NORMALIZ_DLL_EXPORT extern long split_index_rounds; // transports the split index option after adding the rounds
 NORMALIZ_DLL_EXPORT extern long split_refinement; // transports the refinement of the split
