@@ -337,7 +337,7 @@ void Output<Integer>::write_matrix_mod(const Matrix<Integer>& M) const {
 
 template <typename Integer>
 void Output<Integer>::write_matrix_lat(const Matrix<Integer>& M) const {
-    if (ext == true) {
+    if (lat == true) {
         M.print(name, "lat");
     }
 }
@@ -1212,32 +1212,49 @@ void Output<Integer>::writeSeries(ofstream& out, const HilbertSeries& HS, string
     }
 }
 
-//---------------------------------------------------------------------------
-
+template <typename Integer>
+void Output<Integer>::write_induction_matrices() {
 
+    string name_open = name + ".ind";
+    ofstream ind_out(name_open);
+    write_vec_vec_Mat(Result->getInductionMatrices(), ind_out);
+}
 
 //---------------------------------------------------------------------------
 
 template <typename Integer>
 void Output<Integer>::write_files() {
 
+    if(Result->isComputed(ConeProperty::InductionMatrices))
+        write_induction_matrices();
+
+    if(Result->isComputed(ConeProperty::SingleFusionRing)){
+        write_single_fusion_file(Result->getFusionBasicCone(), name, Result->getEmbeddingDim(), Result->getSingleFusionRing(), no_matrices_output);
+        return;
+    }
+
     if(Result->isComputed(ConeProperty::FusionRings) || Result->isComputed(ConeProperty::SimpleFusionRings)){
         if(Result->isComputed(ConeProperty::FusionRings)){
             write_fusion_files(Result->getFusionBasicCone(), name, Result->isComputed(ConeProperty::SimpleFusionRings),
                             Result->isComputed(ConeProperty::NonsimpleFusionRings), Result->getEmbeddingDim(),
                             Result->getSimpleFusionRingsMatrix(), Result->getNonsimpleFusionRingsMatrix(),
-                            no_matrices_output);
+                            no_matrices_output, false);
         }
         else{ // only soimple computed
             Matrix<Integer> Zero;
             write_fusion_files(Result->getFusionBasicCone(),name, Result->isComputed(ConeProperty::SimpleFusionRings),
                             Result->isComputed(ConeProperty::NonsimpleFusionRings), Result->getEmbeddingDim(),
                             Result->getSimpleFusionRingsMatrix(), Zero,
-                            no_matrices_output);
+                            no_matrices_output,false);
         }
         return;
     }
 
+    if(Result->isComputed(ConeProperty::ModularGradings)){
+        write_modular_gradings(name, Result->getModularGradings());
+        return;
+    }
+
     size_t i, nr;
     vector<libnormaliz::key_t> rees_ideal_key;
 
@@ -1468,10 +1485,10 @@ void Output<Integer>::write_files() {
         }
         if (homogeneous && Result->isComputed(ConeProperty::IsSerreR1)) {
             if (Result->isIntegrallyClosed()) {
-                out << "original monoid satifies Serre cindition R1" << endl;
+                out << "original monoid satisfies Serre condition R1" << endl;
             }
             else {
-                out << "original monoid vioaltes Serre cindition R1" << endl;
+                out << "original monoid violates Serre condition R1" << endl;
             }
         }
         out << endl;
@@ -1659,9 +1676,12 @@ void Output<Integer>::write_files() {
         }
 
        if (Result->isComputed(ConeProperty::SingleLatticePoint)) {
+           // output can be suppressed in tests because non-uniqueness of the lattice point
             if (Result->getSingleLatticePoint().size() > 0) {
-                out << "Lattice point:" << endl;
-                out <<  Result->getSingleLatticePoint();
+                if(!no_matrices_output){
+                    out << "Lattice point:" << endl;
+                    out <<  Result->getSingleLatticePoint();
+                }
             }
             else
                 out << "No lattice point found" << endl;
@@ -1916,13 +1936,49 @@ void Output<Integer>::write_files() {
     write_Stanley_dec();
 }
 
+void write_modular_gradings(const string& name, const vector<vector<dynamic_bitset> >& modular_gradings){
+
+    string name_open = name + ".out";  // preparing output files
+    ofstream out(name_open);
+    out << modular_gradings.size() << " modular gradings" << endl;
+    out << endl;
+    out << "***********************************************************************" << endl << endl;
+    out << modular_gradings.size() << " modular gradings:" << endl;
+    for(size_t i = 0; i < modular_gradings.size(); ++i){
+
+        out << "modular grading " << i + 1 << endl << endl;
+        for(auto& p: modular_gradings[i])
+            out << bitset_to_key(p);
+        out << "---------------------" << endl;
+    }
+}
+
+template <typename Integer>
+void write_single_fusion_file(const FusionBasic fusion_basic, const string& name,
+                        size_t embdim, vector<Integer> SingleFusionRing,
+                        const bool no_matrices_output) {
+
+    Matrix<Integer> Simple, Nonsimple;
+    Matrix<Integer> Fusion;
+    if(SingleFusionRing.size() > 0){
+        Fusion.resize(0,SingleFusionRing.size());
+        Fusion.append(SingleFusionRing);
+
+    }
+
+    split_into_simple_and_nonsimple(fusion_basic, Simple, Nonsimple, Fusion, libnormaliz::verbose);
+
+    write_fusion_files(fusion_basic, name, true,true, embdim,Simple, Nonsimple,no_matrices_output, true);
+
+    return;
+}
 
 template <typename Integer>
 void write_fusion_files(const FusionBasic fusion_basic, const string& name, const bool simple_fusion_rings,
                         const bool non_simple_fusion_rings,
                         size_t embdim, const Matrix<Integer>& SimpleFusionRings,
                         const Matrix<Integer>& NonsimpleFusionRings,
-                        const bool no_matrices_output) {
+                        const bool no_matrices_output, const bool only_one) {
 
     string name_open = name + ".out";  // preparing output files
     const char* file = name_open.c_str();
@@ -1947,7 +2003,10 @@ void write_fusion_files(const FusionBasic fusion_basic, const string& name, cons
     bool fusion_rings = simple_fusion_rings && non_simple_fusion_rings;
     size_t total_nr_fusion_rings = NonsimpleFusionRings.nr_of_rows() + SimpleFusionRings.nr_of_rows();
     if(fusion_rings){
-        out << total_nr_fusion_rings << " fusion rings up to isomorphism" << endl;
+        if(only_one && total_nr_fusion_rings > 0)
+            out << total_nr_fusion_rings << " fusion rings up to isomorphism (only single fusion ring  asked for)" << endl;
+        else
+            out << total_nr_fusion_rings << " fusion rings up to isomorphism" << endl;
     }
     if(simple_fusion_rings){
         out << SimpleFusionRings.nr_of_rows() << simple_fusion_text << endl;
@@ -1970,7 +2029,7 @@ void write_fusion_files(const FusionBasic fusion_basic, const string& name, cons
 
         vector<Integer> dehom(embdim);
         dehom.back() = 1;
-        out << "Embedding dimension " << embdim << endl;
+        out << "Embedding dimension = " << embdim << endl;
         out << endl;
         out << "dehomogenization" << endl;
         out << dehom;
@@ -2006,6 +2065,7 @@ void write_fusion_files(const FusionBasic fusion_basic, const string& name, cons
         fusion.write_all_data_tables(AllFusionRings, ftb_out);
         ftb_out.close();
     }
+
 }
 
 #ifndef NMZ_MIC_OFFLOAD  // offload with long is not supported
@@ -2022,24 +2082,38 @@ template void write_fusion_files(const FusionBasic fusion_basic, const string& n
                                  const bool simple_fusion_rings,
                                  size_t embdim, const Matrix<long long>& SimpleFusionRings,
                                  const Matrix<long long>& NonSimpleFusionRings,
-                                 const bool no_matrices_output);
+                                 const bool no_matrices_output, const bool only_one);
 
 template void write_fusion_files(const FusionBasic fusion_basic, const string& name, const bool non_simple_fusion_rings,
                                  const bool simple_fusion_rings,
                                  size_t embdim, const Matrix<long>& SimpleFusionRings,
                                  const Matrix<long>& NonSimpleFusionRings,
-                                 const bool no_matrices_output);
+                                 const bool no_matrices_output, const bool only_one);
 
 template void write_fusion_files(const FusionBasic fusion_basic, const string& name, const bool non_simple_fusion_rings,
                                  const bool simple_fusion_rings,
                                  size_t embdim, const Matrix<mpz_class>& SimpleFusionRings,
                                  const Matrix<mpz_class>& NonSimpleFusionRings,
-                                 const bool no_matrices_output);
+                                 const bool no_matrices_output, const bool only_one);
 #ifdef ENFNORMALIZ
 template void write_fusion_files(const FusionBasic fusion_basic, const string& name, const bool non_simple_fusion_rings,
                                  const bool simple_fusion_rings,size_t embdim,
                                  const Matrix<renf_elem_class>& SimpleFusionRings,
                                  const Matrix<renf_elem_class>& NonSimpleFusionRings,
-                                 const bool no_matrices_output);
+                                 const bool no_matrices_output, const bool only_one);
 #endif
+
+template void write_single_fusion_file(const FusionBasic fusion_basic, const string& name,
+                        size_t embdim, vector<long> SingleFusionRing, const bool no_matrices_output);
+
+template void write_single_fusion_file(const FusionBasic fusion_basic, const string& name,
+                        size_t embdim, vector<long long> SingleFusionRing, const bool no_matrices_output);
+
+template void write_single_fusion_file(const FusionBasic fusion_basic, const string& name,
+                        size_t embdim, vector<mpz_class> SingleFusionRing, const bool no_matrices_output);
+#ifdef ENFNORMALIZ
+template void write_single_fusion_file(const FusionBasic fusion_basic, const string& name,
+                        size_t embdim, vector<renf_elem_class> SingleFusionRing, const bool no_matrices_output);
+#endif
+
 }  // namespace libnormaliz
