@@ -160,6 +160,8 @@ class Output {
     void writeWeightedEhrhartSeries(ofstream& out) const;
     void writeSeries(ofstream& out, const HilbertSeries& HS, string HilbertOrEhrhart) const;
 
+    void write_induction_matrices();
+
     void write_perms_and_orbits(ofstream& out,
                                 const vector<vector<key_t> >& Perms,
                                 const vector<vector<key_t> >& Orbits,
@@ -171,7 +173,14 @@ template <typename Integer>
 void write_fusion_files(const FusionBasic basic, const string& name, const bool non_simple_fusion_rings, const bool simple_fusion_rings,
                                          size_t embdim, const Matrix<Integer>& SimpleFusionRings,
                                          const Matrix<Integer>& NonSimpleFusionRings,
-                                         const bool no_matrices_output);
+                                         const bool no_matrices_output, const bool only_one);
+
+void write_modular_gradings(const string& name, const vector<vector<dynamic_bitset> >& modular_gradings);
+
+template <typename Integer>
+void write_single_fusion_file(const FusionBasic fusion_basic, const string& name,
+                        size_t embdim, vector<Integer> SingleFusionRing,
+                        const bool no_matrices_output);
 
 }  // namespace libnormaliz
 
