@@ -39,6 +39,12 @@
 namespace libnormaliz {
 using std::vector;
 
+const size_t max_nr_new_latt_points_total = 100000; // before we go one level up in the recursion
+const size_t max_nr_new_latt_points_patching = 4000; // the same for patching
+const size_t nr_extensions_for_elimination_equs = 10000;
+const size_t nr_extensions_for_elimination_inequs = 10000;
+const size_t nr_extensions_for_elimination_automs = 10000;
+
 // the project-and-lift algorithm for lattice points in a polytope
 
 template <typename Integer>
@@ -49,6 +55,12 @@ class ProjectAndLift {
     template <typename, typename>
     friend class ProjectAndLift;
 
+    size_t max_nr_new_latt_points_total;
+    size_t max_nr_new_latt_points_patching;
+    size_t nr_extensions_for_elimination_equs;
+    size_t nr_extensions_for_elimination_inequs;
+    size_t nr_extensions_for_elimination_automs;
+
     list<vector<IntegerRet> > start_list; // list of lattice points to start from
                                           // and to be lifted to full dimension
 
@@ -68,11 +80,16 @@ class ProjectAndLift {
 
     size_t StartRank;
 
+    list<vector<IntegerRet> > FreeVect;
+    vector<list<vector<IntegerRet> > > FreeVectThread;
+    void store_new_vector(const vector<IntegerRet>& new_vect, const int tn);
+
     vector<list<vector<IntegerRet> > > Deg1Thread;
     vector<vector<num_t> > h_vec_pos_thread;
     vector<vector<num_t> > h_vec_neg_thread;
 
     list<vector<IntegerRet> > Deg1Points; // all Deg1Points found
+    list<vector<short> > ShortDeg1Points; // all Deg1Points found
     vector<IntegerRet> SingleDeg1Point;
     vector<IntegerRet> excluded_point;
     IntegerRet GD;
@@ -106,6 +123,8 @@ class ProjectAndLift {
     bool first_solution_printed;
     bool fusion_rings_computation;
     bool stored_local_solutions;
+    bool use_short_int;
+    bool no_heuristic_minimization;
 
     bool system_unsolvable;
 
@@ -124,6 +143,8 @@ class ProjectAndLift {
 
     size_t nr_time_printed;
 
+    struct timeval stop_ckeck_begin;
+
     // data for patching method
     vector<dynamic_bitset> Indicator; // indicaor of nonzero coordinates in inequality
     dynamic_bitset upper_bounds; // indicator of inequalities giving upper boounds
@@ -132,7 +153,8 @@ class ProjectAndLift {
     // data for patching depending on coordinates
     vector<key_t> InsertionOrderPatches;
     vector<key_t> LevelPatches; // index of coord in InsertionOrderPatches
-    vector<Matrix<IntegerRet> > AllLocalSolutions; // "local" solutions that will be patched
+    vector<vector<vector<IntegerRet> > > AllLocalSolutions; // "local" solutions that will be patched
+    vector<vector<vector<short> > > AllShortLocalSolutions; // the same in short int format
 
     vector< map< vector<IntegerRet>, map< vector<IntegerRet>, vector<key_t>  > > >  AllLocalSolutions_by_intersection_and_cong;
 
@@ -161,7 +183,7 @@ class ProjectAndLift {
     Matrix<double> WeightOfCoord;
     Matrix<IntegerPL> DefiningSupps;
 
-    Matrix<IntegerRet> SavedLocalSolutions;
+    // Matrix<IntegerRet> SavedLocalSolutions;
 
     vector<double> ExpectedNrRounds;
     vector<double> TimeToLevel;
@@ -184,8 +206,9 @@ class ProjectAndLift {
     void find_single_point();
     void compute_latt_points();
     void compute_latt_points_float();
-    void finalize_latt_point(const vector<IntegerRet>& NewPoint, const int tn);
+    void finalize_latt_point(vector<IntegerRet> NewPoint, const int tn);
     void collect_results(list<vector<IntegerRet> >& Deg1PointsComputed);
+    void splice_into_short_deg1_points(list<vector<IntegerRet> >& Deg1PointsComputed);
 
     void compute_projections(size_t dim,
                              size_t down_to,
@@ -217,7 +240,10 @@ class ProjectAndLift {
     void prepare_split(list<vector<IntegerRet> >& LatticePoints, const key_t& this_patch);
     void read_split_data();
 
-    bool import_local_solutions(const key_t& this_patch);
+
+    void compute_local_solutions(const key_t this_patch, list<vector<IntegerRet> >& start_list);
+    void compute_local_solutions_for_saving();
+    dynamic_bitset ImportedLocalSolutions; // registers the levels with imported local solutions
 
     // void make_LLL_coordinates();
 
@@ -234,6 +260,7 @@ class ProjectAndLift {
     void set_excluded_point(const vector<IntegerRet>& excl_point);
     void set_grading_denom(const IntegerRet GradingDenom);
     void set_verbose(bool on_off);
+    void set_short_int(bool on_off);
     void set_LLL(bool on_off);
     void set_no_relax(bool on_off);
     void set_primitive();
@@ -249,12 +276,15 @@ class ProjectAndLift {
     void set_linear_order_patches(const bool on_off);
     void set_cong_order_patches(const bool on_off);
     void set_distributed_computation(const bool on_off);
+    void set_no_heuristic_minimization(bool on_off);
 
     void compute(bool do_all_points = true, bool lifting_float = false, bool count_only = false);
     void compute_only_projection(size_t down_to);
 
     void putSuppsAndEqus(Matrix<IntegerPL>& SuppsRet, Matrix<IntegerPL>& EqusRet, size_t in_dim);
     void put_eg1Points_into(Matrix<IntegerRet>& LattPoints);
+    void put_deg1Points_into(vector<vector< IntegerRet> >& LattPoints); // we have no matrices for sjort
+    void put_short_deg1Points_into(vector<vector<short> >& ShortLattPoints); // therefore vector<vector >
     void put_single_point_into(vector<IntegerRet>& LattPoint);
     void get_h_vectors(vector<num_t>& pos, vector<num_t>& neg) const;
 
@@ -282,6 +312,7 @@ ProjectAndLift<IntegerPL, IntegerRet>::ProjectAndLift(const ProjectAndLift<Integ
     verbose = Original.verbose;
     no_relax = Original.no_relax;
     only_single_point = false;
+    use_short_int = false;
     convert(GD, Original.GD);
     AllSupps.resize(EmbDim + 1);
     AllCongs.resize(EmbDim + 1);
