@@ -46,6 +46,7 @@ using namespace std;
 #include "libnormaliz/vector_operations.h"
 #include "libnormaliz/project_and_lift.h"
 #include "libnormaliz/fusion.h"
+#include "libnormaliz/induction.h"
 
 using namespace libnormaliz;
 
@@ -62,7 +63,7 @@ void printHeader() {
 #endif
     cout << "                                                       \\...|" << endl;
     cout << "     (C) The Normaliz Team, University of Osnabrueck    \\..|" << endl;
-    cout << "                        May  2024                        \\.|" << endl;
+    cout << "                      October  2024                      \\.|" << endl;
     cout << "                                                          \\|" << endl;
     string optional_packages = package_string();
     if (optional_packages.size() > 0) {
@@ -222,6 +223,39 @@ int main(int argc, char* argv[]){
         verboseOutput() << "Command line: " << command_line << endl;
     }
 
+    /* vector<long long> our_type = {1,1,2,6};
+    vector<unsigned int> our_dual = {0,1,2,3};
+    vector<long long> our_ring = {0,0,0,1,0,1,1,0,2,5,1}; */
+
+    /* vector<long long> our_type = {1,1,2};
+    vector<unsigned int> our_dual = {0,1,2};
+    vector<long long> our_ring ={0,0,1,1,1}; */
+
+    /* vector<long long> our_type = {1,1,1,3};
+    vector<unsigned int> our_dual = {0,2,1,3};
+    vector<long long> our_ring ={0,1,0,0,0,1,2,1}; */
+
+    /* vector<long long> our_type = {1,1,4,4,6};
+    vector<unsigned int> our_dual = {0,1,3,2,4};
+    vector<long long> our_ring ={0,0,0,1,0,0,1,0,1,1,0,2,1,1,2,3,1}; */
+
+    /* vector<long long> our_type = {1,5,5,5,6,7,7};
+    vector<unsigned int> our_dual = {0,1,2,3,4,5,6};
+    vector<long long> our_ring ={1,1,0,0,1,1,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,1,1,0,1,1,1,1,1,1,1,1,1,1,0,1,1,1,1,1,1,1,1,1,1,1,2,1,2,1,2,2,1,1}; */
+
+
+    /*
+
+    Induction<long long> Indu(our_type, our_dual, our_ring);
+
+    Indu.start_low_parts();
+    Indu.from_low_to_full();
+
+    exit(0);
+    */
+
+
+
     /*Matrix<long long> FFT(1,4);
     FFT[0] = {1,1,2,2};
     Cone<long long> TT(Type::fusion_type, FFT);
